.pragma library

//canvas object from .pragma
var canvas = 0;
var chart = 0;

//enables debugging
var debug_enabled = 0;

//measurements setted in QML
var canvasHeight = 0;
var canvasWidth = 0;
var canvasXOffset = 0;
var canvasYOffset = 0;

//array of header labels(times)
var xLabels = new Array();

function debug(text)
{
    if (debug_enabled)
        console.debug(text);
}

function refresh()
{
    canvas.requestPaint();
}

//main draw function
function draw()
{
    var context = canvas.getContext("2d");
    context.clearRect(0, 0, canvas.width, canvas.height);
    context.save();
    context.globalAlpha = canvas.alpha;

    drawGrid(context);
    drawTemperatures(context);
    drawCurrentTime(context);
    context.restore();
}

//draw background grid
function drawGrid(context)
{
    //remove all xLabels
    while (xLabels.length > 0)
    {
        var label = xLabels.pop();
        label.text = "";
        label.destroy();
    }

    var maxHSections = 24;
    var hSectionSize = canvasWidth/maxHSections;

    var hours = chart.xAxisHours;
    var startX = 0, startY = 0, endX = 0, endY = 0;

    //draw vertical lines
    for (var i = 1 ; i < hours.length - 1; i++)
    {
        startX = hours[i]*hSectionSize + canvasXOffset;
        startY = canvas.height;
        endX = hours[i]*hSectionSize + canvasXOffset;
        endY = canvasYOffset;
        drawLine(context, startX, startY, endX, endY, chart.gridColor,1);
        //create and add hourLabel to the array
        xLabels.push(Qt.createQmlObject("import QtQuick 2.0;Text{text:\"" + hours[i] +":00\"; y:" + canvasYOffset + " - height; x:" + hours[i]*hSectionSize + "- width/2; color:\"" + chart.trendColor + "\"}", canvas, "labels"));
    }

    //draw horizontal lines
    var vSectionSize = canvasHeight/(chart.gridHorizontalLinesCount + 1);
    for (var i = 1 ; i < chart.gridHorizontalLinesCount +1  ; i++)
    {
        startX = canvasXOffset;
        startY = i * vSectionSize + canvasYOffset;
        endX = canvasXOffset+canvas.width;
        endY = i*vSectionSize + canvasYOffset;

        drawLine(context, startX, startY, endX, endY, chart.gridColor,1);
    }
}

//draw current time vertical bar
function drawCurrentTime(context)
{
    var currentMinutes = parseFloat(Qt.formatDateTime(new Date(), "m")) + (parseFloat(Qt.formatDateTime(new Date(), "h")) * 60);
    var currentTimeWidth = 4;
    var currentTimeColor = "#DD4814";
    var position = ((currentMinutes * canvas.width)/(24 * 60)) - (currentTimeWidth/2);

    drawLine(context,position+canvasXOffset, canvas.height,position+canvasXOffset,canvasYOffset+1, currentTimeColor, currentTimeWidth);
}

//draw temperature points and lines on the chart
function drawTemperatures(context)
{
    context.strokeStyle = chart.trendColor;
    context.lineWidth = chart.trendWidth;

    var maxTemp = -999;
    var minTemp = 999;
    var circleColor = "#DD4814";
    var circleRadius = 4;
    var temperatures = chart.temperatures;

    //determine min and max temp
    for (var i = 0 ; i < temperatures.length ; i++)
    {
        if (parseFloat(temperatures[i].temp) > maxTemp)
            maxTemp = temperatures[i].temp;
        if (parseFloat(temperatures[i].temp) < minTemp)
            minTemp = temperatures[i].temp;
    }

    var positions = new Array();

    //draw temperature points
    for (var i = 0 ; i < temperatures.length ; i++)
    {
        //get time and temp from array
        var temp = temperatures[i].temp;
        var times = temperatures[i].time.split(":");
        var time = (parseFloat(times[0]) * 60) + parseFloat(times[1]);

        //count X and Y based on canvas dimensions and offsets
        var posX = canvasXOffset + ((time * canvas.width)/(24 * 60)) - (chart.trendWidth/2);
        var posY = (canvasHeight) - (canvasHeight - canvasYOffset - circleRadius) * ((parseInt(temp) - Math.abs(minTemp)) / (maxTemp - minTemp));
        if (posY == canvasHeight)
            posY -= circleRadius;

        //draw temperature point
        //drawCircle(context, posX, posY, circleRadius, circleColor);
        positions.push({'posY':posY, 'posX':posX})
    }

    drawTemperatureLines(context,positions,circleColor);
}

//draw lines connecting temperature points
//WORK IN PROGRESS. should be smooth paths
function drawTemperatureLines(context, positions, color)
{
    var posX = 0, posY = 0, prevX, prevY;

    context.save();
    context.strokeStyle = chart.trendColor;
    context.lineWidth = 2;
    context.lineJoin  = "round";
    context.beginPath();

    for (var i = 0 ; i < positions.length ; i++)
    {
        posY = positions[i].posY;
        posX = positions[i].posX;

        if (i == 0)
        {
            context.moveTo(posX, posY);
        }
        else
        {
            prevX = positions[i-1].posX;
            prevY = positions[i-1].posY;
            context.lineTo(posX, posY);
        }
    }
    context.stroke();
    context.restore();
}

//general function for circle drawing
function drawCircle(context, x, y, radius, color)
{
  context.save();
  context.fillStyle = color;
  context.beginPath();
  context.arc(x, y, radius,0,Math.PI*2,true); // Outer circle
  context.fill();
  context.restore();
}

//general function for line drawing
function drawLine(context, startX, startY, endX, endY, color, width)
{
    context.save();
    context.lineWidth = width;
    context.strokeStyle = color;
    context.beginPath();
    context.moveTo(startX,startY);
    context.lineTo(endX,endY);
    context.closePath();
    context.stroke();
    context.restore();
}
