import QtQuick 2.0
import Ubuntu.Components 0.1
import "./" as Components

Rectangle {
    id: currentWeather

    // For Status I take the same condition codes from OpenWeatherMap (http://openweathermap.org/wiki/API/Weather_Condition_Codes)
    property int condition
    property string icon
    property int currentTemp
    property int minTemp
    property int maxTemp
    property string scale: (mainView.settings["units"] === "imperial") ? "F" : "C"

    width: parent.width
    height: childrenRect.height+units.gu(10)
    anchors.horizontalCenter: parent.horizontalCenter

    Components.WeatherConditionIconComponent {
        id: currentCondition
        width: units.gu(30)
        height: units.gu(30)
        anchors.horizontalCenter: parent.horizontalCenter
        condition: currentWeather.icon

        NumberAnimation on opacity {
            id: createAnimation
            easing.type: Easing.Linear
            from: 0
            to: 1
            duration: 1000
        }

        Component.onCompleted: {
            createAnimation.start()
        }
    }

    Rectangle {
        id: rectangle1
        width: units.gu(50)
        height: units.gu(10)
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: currentCondition.bottom
        anchors.topMargin: 0
        color: "#00000000"

        Column {
            id: column1
            width: units.gu(5)
            height: units.gu(5)
            anchors.rightMargin: 0
            anchors.verticalCenter: parent.verticalCenter
            anchors.right: tempCurrent.left

            Label {
                text: i18n.tr("Max.")
                anchors.horizontalCenter: parent.horizontalCenter
                font.pixelSize: FontUtils.sizeToPixels("x-small")
                horizontalAlignment: Text.AlignHCenter
            }

            Label {
                id: tempMax
                text: maxTemp+"°"+currentWeather.scale
                anchors.horizontalCenter: parent.horizontalCenter
                font.pixelSize: FontUtils.sizeToPixels("medium")
                horizontalAlignment: Text.AlignHCenter
            }
        }

        Text {
            width: units.gu(17)
            height: units.gu(10)
            id: tempCurrent
            objectName: "CurrentTempText"
            text: currentTemp+String("°")+currentWeather.scale
            style: Text.Normal
            font.bold: false
            font.family: "Ubuntu"
            verticalAlignment: Text.AlignVCenter
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            font.pointSize: 52
            horizontalAlignment: Text.AlignHCenter
        }

        Column {
            id: column2
            width: units.gu(5)
            height: units.gu(5)
            anchors.leftMargin: 0
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: tempCurrent.right

            Label {
                text: i18n.tr("Min.")
                horizontalAlignment: Text.AlignHCenter
                anchors.horizontalCenter: parent.horizontalCenter
                font.pixelSize: FontUtils.sizeToPixels("x-small")
            }

            Label {
                id: tempMin
                text: minTemp+"°"+currentWeather.scale
                horizontalAlignment: Text.AlignHCenter
                anchors.horizontalCenter: parent.horizontalCenter
                font.pixelSize: FontUtils.sizeToPixels("medium")
            }
        }
    }
}
