import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem
import Ubuntu.Components.Popups 0.1

Page {
    id: locationManagerPage
    objectName: "LocationManagerPage"
    title: i18n.tr("Edit locations")
    visible: false

    property bool locationsChanged: false

    tools: ToolbarItems {
        locked: true
        opened: (locationModel.count > 0) ? true : false
        back: ToolbarButton {
            objectName: "BackButton"
            text: i18n.tr("Back")
            iconSource: Qt.resolvedUrl("../resources/images/back@18.png")
            onTriggered: {
                if(locationsChanged) {
                    mainView.refreshData()
                    locationsChanged = false;
                }
                // handle dummy "current location" item
                currentLocationItem.visible = false
                locationLookupItem.visible = true
                lookupItemAddButton.visible = true

                if(pageStack.depth === 2) pageStack.pop()
            }
        }
    }

    function loadData() {
        storage.getLocations(fillLocationsList);
    }

    function checkLocationExists(location) {
        for(var x=0;x<locationModel.count;x++) {
            var loc = locationModel.get(x);
            if(loc.service === location.service
                    && loc.service_id === location.service_id) {
                existsNotification.show()
                return true;
            }
        }
        return false;
    }

    function fillLocationsList(locations) {
        locationModel.clear()
        for(var x=0;x<locations.length;x++) {
            var dbId = locations[x].db.id,
                location = locations[x].location;
            // add db-id to the location object
            location.dbId = dbId;
            locationModel.append(locations[x].location);
        }
    }

    function addLocation(location) {
        if(!checkLocationExists(location)) {
            storage.insertLocation({location:location});
            loadData()
            locationsChanged = true;
        }
    }


    Dialog {
        id:existsNotification
        title: i18n.tr("Location already added.")
        Button {
            text: i18n.tr("OK")
            onClicked: PopupUtils.close(existsNotification)
        }
    }

    ListModel {
        id: locationModel
    }

    Column {
        anchors.fill: parent
        Rectangle {
            color: "#D6D6D6"
            width:parent.width
            height: units.gu(0.3)
        }
        Rectangle {
            width: parent.width
            height: units.gu(5)
            Label {
                anchors.verticalCenter: parent.verticalCenter
                text: " "+i18n.tr("Current location")
                fontSize: "large"
            }
        }
        Rectangle {
            color: "#D6D6D6"
            width:parent.width
            height: units.gu(0.3)
        }
        ListItem.Standard {
            id: locationLookupItem
            text: i18n.tr("Lookup location")+" (Dummy)"
            progression: true
            onClicked: {
                print("TODO: lookup current location")
                visible = false
                currentLocationItem.visible = true;
            }
        }
        ListItem.Standard {
            id: currentLocationItem
            visible: false
            text: i18n.tr("London")
            //icon:  Qt.resolvedUrl("../resources/images/refresh_icon.png")
            control: Button {
                id: lookupItemAddButton
                anchors.verticalCenter: parent.verticalCenter
                text: i18n.tr("add")
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        // add dummy location
                        addLocation({"service_id":2643743,"name":"London","country":"GB","service":"openweathermap"})
                        lookupItemAddButton.visible = false;
                    }
                }
            }
        }
        Rectangle {
            id:test2
            width: parent.width
            height: units.gu(5)
            Label {
                anchors.verticalCenter: parent.verticalCenter
                text: " "+i18n.tr("World")
                fontSize: "large"
            }
        }
        Rectangle {
            color: "#D6D6D6"
            width:parent.width
            height: units.gu(0.3)
        }
        Rectangle {
            width: parent.width
            clip:true
            color:"transparent"
            height: units.gu(40)
            ListView {
                objectName: "LocationList"
                anchors.fill: parent
                model: locationModel
                delegate: ListItem.Standard {
                    text: model.name
                    removable: true
                    onItemRemoved: {
                        var location = locationModel.get(index)
                        locationsChanged = true;
                        storage.clearLocation(location.dbId);
                        locationModel.remove(index)
                    }
                    backgroundIndicator: Rectangle {
                        anchors.fill: parent
                        color: "gray"
                    }
                }
                footer: ListItem.Standard {
                    objectName: "AddCityListItem"
                    text: i18n.tr("Add city")
                    progression: true
                    onClicked: pageStack.push(addLocationPage)
                }
            }
        }
    }
}
