import QtQuick 2.0
import Ubuntu.Components.Popups 0.1
import Ubuntu.Components 0.1

Tab {
    id: locationTab
    objectName: "LocationTab"
    property int locationIndex: 0
    property var locationData: {}

    function formatTimestamp(timestamp, format) {
        var date = new Date(timestamp*1000);
        return Qt.formatDate(date, format)
    }

    function formatTimestampToTime(timestamp, format) {
        var date = new Date(timestamp*1000);
        return Qt.formatTime(date, format)
    }

    Component.onCompleted: {
        var locData = mainView.locationsList[locationIndex],
            currentData = locData.current.results,
            units = (mainView.settings.units === 'imperial') ? 'imperial' : 'metric';

        // set location data as property
        locationData = locData;

        // set today date
        var todayStr = formatTimestamp(currentData.timestamp, 'dddd, dd MMMM yyyy');
        todayDateComponent.dateString = todayStr+" - "+ formatTimestampToTime(currentData.timestamp, 'HH:mm');
        todayDateComponent.renderText()

        // set current Condition
        currentCondition.condition = currentData.condition.id;
        currentCondition.icon = currentData.condition.icon;
        currentCondition.currentTemp =  currentData[units].temp;
        currentCondition.minTemp = currentData[units].temp_min;
        currentCondition.maxTemp = currentData[units].temp_max;

        // set daily forecasts
        var dailyForecasts = locationData.daily.results,
            dailyLength = dailyForecasts.length;
        for(var x=1;x<dailyLength;x++) {
            dayForecastModel.append({
                dateRel: "",//Tomorrow",
                date: formatTimestamp(dailyForecasts[x].timestamp, 'dddd, dd MMMM yyyy'),
                temp: dailyForecasts[x][units].max,
                tempMin: dailyForecasts[x][units].min,
                cond: dailyForecasts[x].condition.id,
                condIcon: dailyForecasts[x].condition.icon
            });
        }
    }

    // Menu for options
    page: Page {
        id: locationPage
        tools: ToolbarItems {
            id: pageTools
            ToolbarButton {
                objectName: "RefreshButton"
                action:Action {
                    id: refreshAction
                    objectName: "RefreshAction"
                    iconSource: Qt.resolvedUrl("../resources/images/refresh_icon.png")
                    text: i18n.tr("Refresh")

                    onTriggered: {
                        mainView.refreshData(false, true);
                    }
                }
            }
            ToolbarButton {
                objectName: "EditButton"
                action:Action {
                    id: editLocationAction
                    iconSource: Qt.resolvedUrl("../resources/images/add_icon.png")
                    text: i18n.tr("Edit")

                    onTriggered: {
                        mainView.showLocationManager()
                    }
                }
            }
            ToolbarButton {
                objectName: "SettingsButton"
                action:Action {
                    id: configAction
                    iconSource: Qt.resolvedUrl("../resources/images/refresh_icon.png")
                    text: i18n.tr("Settings")

                    onTriggered: {
                        mainView.showSettingsPage();
                    }
                }
            }
        }
    }

    ListModel {
        id: dayForecastModel
    }

    Rectangle {
        id:startPage
        width: parent.width
        height: parent.height

        Flickable {
            id: flickable
            width: parent.width
            height: parent.height
            contentHeight: flickContent.height;
            Rectangle {
                id: flickContent
                width:parent.width
                height: childrenRect.height
                DateComponent {
                    id: todayDateComponent
                    //dateRelative: i18n.tr("Today")
                    borderTopVisible: false
                }
                CurrentWeather {
                    id: currentCondition
                    anchors.top: todayDateComponent.bottom
                }
                /*ChartComponent{
                    id: chartComponent
                    anchors.top: currentCondition.bottom
                }*/
                ListView {
                    id: dailyForecastList
                    width: parent.width;
                    height:childrenRect.height
                    anchors.top: currentCondition.bottom
                    model:dayForecastModel
                    interactive: false
                    delegate: Item {
                        id: dailyForecastItem
                        width:parent.width
                        height: childrenRect.height
                        DateComponent {
                            id: dateComponent
                            dateRelative: dateRel
                            dateString: date
                        }
                        DayWeatherComponent {
                            anchors.top: dateComponent.bottom
                            temperature: temp
                            temperatureMin: tempMin
                            condition: cond
                            icon: condIcon
                        }
                    }
                }
            }
        }
    }

}
