# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
# Copyright 2013 Canonical
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.

"""Tests for managing locations in Weather app"""

from __future__ import absolute_import

from testtools.matchers import Equals
from autopilot.matchers import Eventually

from ubuntu_weather_app.tests import WeatherTestCase, DatabaseMixin
from ubuntu_weather_app.tests.weatherdata import locations_data

class TestSettings(WeatherTestCase, DatabaseMixin):
    def setUp(self):
        self.clean_db()
        self.launch_and_quit_app()
        self.save_locations_to_storage(locations_data)
        super(TestSettings, self).setUp()
        self.assertThat(
            self.main_window.get_qml_view().visible, Eventually(Equals(True)))

    def _open_settings_page(self):
        """Opens the settings page"""
        self.main_window.open_toolbar()
        self.assertThat(self.main_window.get_toolbar().opened, Eventually(Equals(True)))
        self.main_window.click_toolbar_button("SettingsButton")

    def test_switch_scale(self):
        """Tests switching the scale in the settings"""
        # first check metric values
        current_temps = self.main_window.get_objects('QQuickText', 'CurrentTempText')
        self.assertThat(current_temps[0].text, Eventually(Equals(u'21°C')))
        self.assertThat(current_temps[1].text, Eventually(Equals(u'26°C')))

        # open the settings and switch to imperial
        self._open_settings_page()
        switch = self.main_window.get_object('CheckBox', 'ImperialSwitch')
        self.assertThat(switch.visible, Eventually(Equals(True)))
        self.assertThat(switch.checked, Eventually(Equals(False)))
        self.pointing_device.click_object(switch)
        self.assertThat(switch.checked, Eventually(Equals(True)))
        self.main_window.click_toolbar_button("BackButton")

        # wait for reload and check the imperial values
        load_indicator = self.main_window.get_object('ActivityIndicator', 'LoadingSpinner')
        self.assertThat(load_indicator.running, Eventually(Equals(False)))
        current_temps = self.main_window.get_objects('QQuickText', 'CurrentTempText')
        self.assertThat(current_temps[0].text, Eventually(Equals(u'69°F')))
        self.assertThat(current_temps[1].text, Eventually(Equals(u'78°F')))

        # switch back to metric values again
        self._open_settings_page()
        switch = self.main_window.get_object('CheckBox', 'ImperialSwitch')
        self.assertThat(switch.visible, Eventually(Equals(True)))
        self.assertThat(switch.checked, Eventually(Equals(True)))
        self.pointing_device.click_object(switch)
        self.assertThat(switch.checked, Eventually(Equals(False)))
        self.main_window.click_toolbar_button("BackButton")

        # wait for reload and check the metric values again
        load_indicator = self.main_window.get_object('ActivityIndicator', 'LoadingSpinner')
        self.assertThat(load_indicator.running, Eventually(Equals(False)))
        current_temps = self.main_window.get_objects('QQuickText', 'CurrentTempText')
        self.assertThat(current_temps[0].text, Eventually(Equals(u'21°C')))
        self.assertThat(current_temps[1].text, Eventually(Equals(u'26°C')))